@@ -1,8 +1,9 @@
 from pydantic import BaseModel, PrivateAttr, Field
 from typing import (Deque, Dict, FrozenSet, List, Optional, Sequence, Set, Tuple, Union, Type, Literal)
 import ruamel.yaml
+from steam_sdk.data.DataAnalysis import PermanentSettings, WorkingFolders
 
-### SUBLEVEL
+### SUB-SUB-LEVEL
 class interface(BaseModel):
     analysis_drivers: str = ''
     interface_arguments: Dict = {}
@@ -34,11 +35,25 @@ class environment(BaseModel):
     type_tabular_data: str = ''
     tabular_data_argument: Dict = {}
 
-######### MAIN LEVEL #####
+######### SUB-LEVEL #####
 class DAKOTA_analysis(BaseModel):
     interface: interface = interface()
     responses: responses = responses()
     variables: variables = variables()
     method: method = method()
     model: model = model()
-    environment: environment = environment()
\ No newline at end of file
+    environment: environment = environment()
+
+class STEAMmodel(BaseModel):
+    name: str = None
+    software: str = None
+    file_model_data: str = None
+    case_model: str = None
+
+############# Main Level ########
+class DAKOTA(BaseModel):
+    DAKOTA_analysis: DAKOTA_analysis = DAKOTA_analysis()
+    PermanentSettings: PermanentSettings = PermanentSettings()
+    WorkingFolders: WorkingFolders = WorkingFolders()
+    STEAMmodel: STEAMmodel = STEAMmodel()
+
