@@ -120,8 +120,8 @@ class Analysis(BaseModel):
         Level 1: Analysis settings
     """
     analysis_type: str = None
-    simulation_time: SimulationTime = SimulationTime()
-    simulation_frequency: SimulationFrequency = SimulationFrequency()
+    simulation_time: Optional[SimulationTime] = SimulationTime()
+    simulation_frequency: Optional[SimulationFrequency] = SimulationFrequency()
 
 ############################
 # Post-processing settings
